@@ -22,8 +22,7 @@ class DataFrameSummary(object):
     TYPE_CONSTANT = 'constant'
     TYPE_UNIQUE = 'unique'
 
-    continuous=[]
-    categorical=[]
+
 
     def __init__(self, df, plot=False):
         self.df = df
@@ -31,6 +30,8 @@ class DataFrameSummary(object):
         self.columns_stats = self._get_stats()
         self.corr = df.corr()
         self.plot = plot
+        self.continuous=[]
+        self.categorical=[]
 
     def __getitem__(self, column):
         if isinstance(column, str) and self._clean_column(column):
